        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>13</strong> miembros: 20 <strong>control</strong><br>0,5,6,7,11,12,13,16,18,27,29,32,34,37,38,39,41,42,44,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>3</strong> miembros: 20 <br>1,2,3,10,14,15,19,21,22,23,24,26,30,31,33,35,45,46,47,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260501 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>28</strong> miembros: 11 <br>4,8,9,17,20,25,28,36,40,43,49';}
}
